@@ -3,7 +3,7 @@ module GrapePathHelpers
   # and required arguments for every Grape::Route.
   class RouteDisplayer
     def route_attributes
-      Grape::API::Instance.decorated_routes.map do |route|
+      Grape::API::Instance.decorated_routes.values.flatten.uniq.map do |route|
         {
           route_path: route.route_path,
           route_method: route.route_method,
