@@ -1,5 +1,6 @@
 require 'spec_helper'
 
+# rubocop:disable Metrics/BlockLength
 describe GrapePathHelpers::AllRoutes do
   Grape::API::Instance.extend described_class
 
@@ -32,6 +33,14 @@ describe GrapePathHelpers::AllRoutes do
         expect(all_routes.map(&:path)).to include(*expected_routes)
       end
     end
+
+    context 'when an API is created via an intermediate class' do
+      it 'includes those routes on both Grape::API::Instance and the base class' do
+        expect(Spec::Support::BaseAPI.all_routes.map(&:origin)).to include('/derived_ping')
+        expect(Grape::API::Instance.all_routes.map(&:origin)).to include('/derived_ping')
+      end
+    end
     # rubocop:enable Metrics/LineLength
   end
 end
+# rubocop:enable Metrics/BlockLength
